@@ -27,6 +27,7 @@
 #include <Lum/Base/Util.h>
 
 #include <Lum/Dlg/About.h>
+#include <Lum/Dlg/ActionDialog.h>
 #include <Lum/Dlg/Help.h>
 #include <Lum/Dlg/Msg.h>
 
@@ -78,14 +79,13 @@ public:
   }
 };
 
-class ScoreView : public Lum::Dialog
+class ScoreView : public Lum::Dlg::ActionDialog
 {
 private:
   HiscoreEntriesModelRef list;
 
 public:
   ScoreView(Sweeper* sweeper)
-  : Dialog()
   {
     Hiscore *score;
 
@@ -96,7 +96,7 @@ public:
     list=new HiscoreEntriesModel(score->list,new HiscoreEntryDataProvider());
   }
 
-  void PreInit()
+  Lum::Object* GetContent()
   {
     Lum::Panel            *panel;
     Lum::Table            *table;
@@ -111,6 +111,7 @@ public:
     table=new Lum::Table();
     table->SetFlex(true,true);
     table->SetMinWidth(Lum::Base::Size::stdCharWidth,30);
+    table->SetMinHeight(Lum::Base::Size::stdCharHeight,10);
     table->SetShowHeader(true);
     table->GetTableView()->SetAutoFitColumns(true);
     table->GetTableView()->SetAutoVSize(true);
@@ -118,16 +119,16 @@ public:
     table->SetHeaderModel(headerModel);
     panel->Add(table);
 
-    panel->AddSpace();
-    panel->Add(Lum::ButtonRow::CreateClose(GetClosedAction(),true,false));
+    return panel;
+  }
 
-    SetMain(panel);
-
-    Dialog::PreInit();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+  {
+    Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
   }
 };
 
-class ScoreEdit : public Lum::Dialog
+class ScoreEdit : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::ActionRef closeAction;
@@ -137,8 +138,7 @@ private:
 
 public:
   ScoreEdit(Sweeper* sweeper, size_t pos)
-  : Dialog(),
-    closeAction(new Lum::Model::Action()),
+  : closeAction(new Lum::Model::Action()),
     name(new Lum::Model::String()),
     pos(pos)
   {
@@ -152,7 +152,7 @@ public:
     Observe(name);
   }
 
-  void PreInit()
+  Lum::Object* GetContent()
   {
     Lum::Grid      *grid;
     Lum::Panel     *panel;
@@ -196,12 +196,13 @@ public:
     }
 
     panel->Add(grid);
-    panel->AddSpace();
-    panel->Add(Lum::ButtonRow::CreateClose(closeAction,true,false));
 
-    SetMain(panel);
+    return panel;
+  }
 
-    Dialog::PreInit();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+  {
+    Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
   }
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
@@ -238,7 +239,7 @@ public:
   }
 };
 
-class SelectTheme : public Lum::Dialog
+class SelectTheme : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::ActionRef              okAction;
@@ -259,7 +260,7 @@ public:
     Observe(selection);
   }
 
-  void PreInit()
+  Lum::Object* GetContent()
   {
     Lum::Panel            *panel;
     Lum::Table            *table;
@@ -283,12 +284,12 @@ public:
     table->SetDoubleClickAction(okAction);
     panel->Add(table);
 
-    panel->AddSpace();
-    panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
+    return panel;
+  }
 
-    SetMain(panel);
-
-    Dialog::PreInit();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+  {
+    Lum::Dlg::ActionDialog::CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
   }
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -318,7 +319,7 @@ public:
   }
 };
 
-class Settings : public Lum::Dialog
+class Settings : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::ActionRef  smallAction;
@@ -335,8 +336,7 @@ public:
 
 public:
   Settings(Sweeper* sweeper)
-  : Dialog(),
-    smallAction(new Lum::Model::Action()),
+  : smallAction(new Lum::Model::Action()),
     mediumAction(new Lum::Model::Action()),
     bigAction(new Lum::Model::Action()),
     themeAction(new Lum::Model::Action()),
@@ -358,7 +358,7 @@ public:
     themeName->Set(::themeName);
   }
 
-  void PreInit()
+  Lum::Object* GetContent()
   {
     Lum::Label       *label;
     Lum::Panel       *panel,*hPanel;
@@ -398,7 +398,7 @@ public:
     array->Add(Lum::Button::Create(L"_Big",bigAction,true));
 
     label->AddLabel(L"Presets:",array);
-    label->AddLabel(L"One mouse button mode:",Lum::Boolean::Create(oneButtonMode));
+    label->AddLabel(L"One button mode:",Lum::Boolean::Create(oneButtonMode));
 
     hPanel=Lum::HPanel::Create(true,false);
 
@@ -411,12 +411,13 @@ public:
 
     label->AddLabel(L"Theme:",hPanel);
     panel->Add(label);
-    panel->AddSpace();
-    panel->Add(Lum::ButtonRow::CreateClose(GetClosedAction(),true,false));
 
-    SetMain(panel);
+    return panel;
+  }
 
-    Dialog::PreInit();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+  {
+    Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
   }
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
